@@ -1,13 +1,12 @@
 package Lorem;
-{
-  $Lorem::VERSION = '0.23.1';
-}
 
+our $VERSION = '0.16';
 our $AUTHORITY = 'cpan:JHALLOCK';
 
 use Lorem::Document;
-use Lorem::Meta::Attribute::Trait::Inherit;
 use Lorem::Surface::Pdf;
+use Lorem::Surface::PrintOperation;
+
 
 sub new_document {
     Lorem::Document->new;
@@ -36,6 +35,12 @@ Lorem - Document creation
 
   $doc->new_header( center => 'Lorem Document' );
 
+  $doc->build( sub {
+
+  $page = $doc->new_page;
+
+  $page->new_text( content => 'Lorem Ipsum' );
+
 
   # save to pdf file
 
@@ -65,7 +70,7 @@ Lorem - Document creation
 
 L<Lorem> is a library for creating/displaying/printing documents.
 
-=head1 ALPHA VERSION
+=head1 BETA VERSION
 
 *THIS IS NEW SOFTWARE. IT IS STILL IN DEVELOPMENT. THE API MAY CHANGE IN FUTURE
 VERSIONS WITH NO NOTICE.*
@@ -98,10 +103,9 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT
 
-This software is Copyright (c) 2010-2012 Jeffrey Ray Hallock.
-
-This is free software, licensed under:
-
-   The Artistic License 2.0 (GPL Compatible)
+    Copyright (c) 2010 Jeffrey Ray Hallock. All rights reserved.
+    This program is free software; you can redistribute it and/or
+    modify it under the same terms as Perl itself.
 
+=cut
 
