@@ -1,7 +1,6 @@
 package Lorem::Document;
-{
-  $Lorem::Document::VERSION = '0.23.1';
-}
+our $VERSION = '0.01';
+
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
@@ -26,7 +25,6 @@ use Lorem::Util;
 
 extends 'Lorem::Element::Box';
 with 'Lorem::Role::HasHeaderFooter';
-with 'Lorem::Role::HasWatermark';
 
 with 'Lorem::Role::ConstructsElement' => { 
     name => 'header',
@@ -50,7 +48,6 @@ with 'Lorem::Role::ConstructsElement' => {
         $new->set_header_margin( $self->header_margin );
         $new->set_footer_margin( $self->footer_margin );
         $new->set_header( $self->header->clone ) if $self->header;
-        $new->set_watermark( $self->watermark->clone ) if $self->watermark;
         $self->append_element( $new );
         return $new;
     }
@@ -67,10 +64,6 @@ has 'builder_func' => (
     reader => 'builder_func',
 );
 
-sub current_page {
-    $_[0]->children->[-1];
-}
-
 sub doc { $_[0] }
 
 sub inner_width {
