@@ -1,7 +1,4 @@
 package Lorem::Element;
-{
-  $Lorem::Element::VERSION = '0.23.1';
-}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
@@ -49,14 +46,6 @@ has 'children' => (
     }
 );
 
-has 'name' => (
-    is => 'rw',
-    isa => 'Str',
-    default => '',
-);
-
-sub add { shift->append_element( @_ )  }
-
 sub append_element {
     my ( $self, @elements ) = @_;
     
