@@ -1,7 +1,4 @@
 package Lorem::Element::Page;
-{
-  $Lorem::Element::Page::VERSION = '0.23.1';
-}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
@@ -11,12 +8,10 @@ use MooseX::StrictConstructor;
 use Cairo;
 use Pango;
 
+use Lorem::Types qw(  );
 use Lorem::Element::TableRow;
-
-
 extends 'Lorem::Element::Box';
 with 'Lorem::Role::HasHeaderFooter';
-with 'Lorem::Role::HasWatermark';
 with 'Lorem::Role::ConstructsElement' => { class => 'Lorem::Element::Div'  };
 with 'Lorem::Role::ConstructsElement' => { class => 'Lorem::Element::Spacer'  };
 with 'Lorem::Role::ConstructsElement' => { class => 'Lorem::Element::Text'  };
@@ -26,8 +21,6 @@ with 'Lorem::Role::ConstructsElement' => {
     class => 'Lorem::Element::HRule',
 };
 
-
-
 sub imprint {
     my ( $self, $cr ) = @_;
     
@@ -36,14 +29,10 @@ sub imprint {
     
     $self->size_request( $cr );
     $self->size_allocate( $cr, 0, 0, $self->parent->width, $self->parent->height );
-    $self->_imprint_watermark( $cr );
     $self->_imprint_borders ( $cr );
     
-    if ( $self->header ) {
-        $self->header->size_request( $cr );
-        $self->header->size_allocate( $cr, 0, 0, $self->parent->width, $self->parent->height );
-        $self->header->imprint( $cr ) if $self->header;
-    }
+    $self->header->size_allocate( $cr, 0, 0, $self->parent->width, $self->parent->height );
+    $self->header->imprint( $cr ) if $self->header;
     
     $_->imprint( $cr ) for ( @{ $self->children } );
     
@@ -52,6 +41,4 @@ sub imprint {
 
 
 
-
-
 1;
