@@ -1,10 +1,5 @@
 package Lorem::Role::HasCoordinates;
-{
-  $Lorem::Role::HasCoordinates::VERSION = '0.23.1';
-}
-
 use Moose::Role;
-use MooseX::SemiAffordanceAccessor;
 
 has 'x' => (
     is => 'rw',
