@@ -1,10 +1,6 @@
 package Lorem::Role::HasDimensions;
-{
-  $Lorem::Role::HasDimensions::VERSION = '0.23.1';
-}
 
 use Moose::Role;
-use MooseX::SemiAffordanceAccessor;
 
 use Lorem::Util qw(percent_of);
 use Lorem::Types qw(LoremStyleDimension LoremStyleLength LoremStyleRelativeLength);
