@@ -1,11 +1,7 @@
 package Lorem::Role::HasHeaderFooter;
-{
-  $Lorem::Role::HasHeaderFooter::VERSION = '0.23.1';
-}
 use Moose::Role;
 
 use Lorem::Types qw( MaybeLoremDoesStamp );
-use MooseX::SemiAffordanceAccessor;
 
 has 'header' => (
     is => 'rw',
