@@ -1,10 +1,6 @@
 package Lorem::Role::HasPadding;
-{
-  $Lorem::Role::HasPadding::VERSION = '0.23.1';
-}
 
 use Moose::Role;
-use MooseX::SemiAffordanceAccessor;
 
 
 use Lorem::Types qw( LoremStyleLength );
