@@ -1,10 +1,6 @@
 package Lorem::Role::Style::HasDimensions;
-{
-  $Lorem::Role::Style::HasDimensions::VERSION = '0.23.1';
-}
 
 use Moose::Role;
-use MooseX::SemiAffordanceAccessor;
 
 use Lorem::Types qw( LoremStyleDimension );
 use MooseX::Types::Moose qw( Undef );
