@@ -1,16 +1,11 @@
 package Lorem::Role::Style::HasText;
-{
-  $Lorem::Role::Style::HasText::VERSION = '0.23.1';
-}
 
 use Moose::Role;
-use MooseX::SemiAffordanceAccessor;
 
 use Lorem::Types qw(LoremStyleFontFamily LoremStyleFontStyle LoremStyleFontSize
 LoremStyleFontWeight LoremStyleFontVariant LoremStyleTextAlign LoremStyleTextAlign
 LoremStyleTextDecoration LoremStyleTextUnderline);
 
-use Lorem::Util qw( color2rgb );
 
 
 has 'font_family' => (
@@ -66,24 +61,6 @@ sub attr_list {
     my $list = Pango::AttrList->new;
     #$list->insert( Pango::Color->parse( $self->color ) );
     
-    my $attr = Pango::AttrFontDesc->new( $self->font_description );
-    $list->insert( $attr );
-    
-    $attr = Pango::AttrUnderline->new( $self->text_underline ) if $self->text_underline;
-    $list->insert( $attr );
-    
-    $attr = Pango::AttrForeground->new( color2rgb ( $self->color ) ) if $self->color;
-    $list->insert( $attr );
-    
-    return $list;
-}
-
-
-
-# this is the server fix
-sub font_description {
-    my ( $self ) = @_;
-    
     my $fd = Pango::FontDescription->new();
     $fd->set_size( $self->font_size * Pango->scale ) if $self->font_size;
     $fd->set_family( $self->font_family ) if $self->font_family;
@@ -91,7 +68,13 @@ sub font_description {
     $fd->set_variant( $self->font_variant ) if $self->font_variant;
     $fd->set_style( $self->font_style ) if $self->font_style;
     
-    return $fd;
+    my $attr = Pango::AttrFontDesc->new( $fd );
+    $list->insert( $attr );
+    
+    $attr = Pango::AttrUnderline->new( $self->text_underline ) if $self->text_underline;
+    $list->insert( $attr );
+    
+    return $list;
 }
 
 
@@ -99,4 +82,5 @@ sub font_description {
 
 
 
+
 1;
