@@ -1,13 +1,12 @@
 package Lorem::Surface::Pdf;
-{
-  $Lorem::Surface::Pdf::VERSION = '0.23.1';
-}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 use MooseX::StrictConstructor;
 extends 'Lorem::Surface';
 
+use Gtk2;
+
 has 'width' => (
     is => 'rw',
     isa => 'Num',
@@ -33,7 +32,7 @@ sub print {
     $doc->set_height( $self->height );
     my $cr = Cairo::Context->create( $surface );
 
-    &{$doc->builder_func}( $doc, $cr ) if $doc->builder_func;
+    #&{$doc->builder_func}( $doc, $cr );
     
     my @pages = @{$doc->children};
 
