@@ -1,14 +1,10 @@
 package Lorem::Types;
-{
-  $Lorem::Types::VERSION = '0.23.1';
-}
 
 use MooseX::Types
     -declare => [ qw(
 LoremAttrTextAlign
 LoremElement
 LoremText
-LoremWatermark
 LoremDoesStamp
 MaybeLoremDoesStamp
 LoremDocumentObject
@@ -54,13 +50,6 @@ coerce LoremText,
     from Str,
     via {  Lorem::Element::Text->new( content => $_ ) };
     
-class_type LoremWatermark,
-    { class => 'Lorem::Element::Watermark' };
-
-coerce LoremWatermark,
-    from LoremElement,
-    via {  Lorem::Element::Watermark->new( content => $_ ) };
-    
 # element attributes
 subtype LoremAttrTextAlign,
     as Str,
@@ -77,7 +66,7 @@ coerce LoremStyle,
 
 subtype LoremStyleBorderWidth,
     as Str,
-    where { $_ =~ /\d+\.?\d*/ ||  $_ =~ /thin|medium|thick/ };
+    where { $_ =~ /thin|medium|thick/ };
 
 subtype LoremStyleBorderStyle,
     as Str,
